@@ -27,5 +27,6 @@ assertLogical = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL,
 #' @useDynLib checkmate c_check_logical
 #' @export
 testLogical = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL) {
-  isTRUE(.Call("c_check_logical", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate"))
+  res = .Call("c_check_logical", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
+  isTRUE(res)
 }
