@@ -14,7 +14,7 @@ SEXP c_check_integerish(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SE
 SEXP c_check_list(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP c_check_logical(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP c_check_matrix(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-SEXP c_check_array(SEXP, SEXP, SEXP, SEXP);
+SEXP c_check_array(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP c_check_named(SEXP, SEXP);
 SEXP c_check_names(SEXP, SEXP);
 SEXP c_check_numeric(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
