@@ -1,6 +1,11 @@
 context("checkEnvironment")
 
 test_that("checkEnvironment", {
+  myobj = new.env()
+  expect_succ(Environment, myobj)
+  myobj = list()
+  expect_fail(Environment, myobj)
+
   ee = new.env(parent = emptyenv())
   ee$yyy = 1
   ee$zzz = 1
@@ -13,7 +18,6 @@ test_that("checkEnvironment", {
   expect_true(testEnvironment(ee, contains = "yyy"))
   expect_true(testEnvironment(ee, contains = c("yyy", "zzz")))
 
-  expect_true(assertEnvironment(ee))
-  expect_error(assertEnvironment(list()))
+  expect_error(assertEnvironment(list()), "environment")
   expect_error(assertEnvironment(ee, "xxx"), "with name")
 })
